<?php

App::uses('BuzzBookingsAppController', 'BuzzBookings.Controller');

class ActivityPackagesController extends BuzzBookingsAppController {

	public $components = array(
		'BuzzTranslate.Translation' => array(
			'fields' => array(
				'name',
				'description'
			)
		)
	);

	public function admin_edit($id = null) {
		parent::admin_edit($id);

		$ActivityPackage = $this->{$this->modelClass};
		$params = [];
		if ($id !== null) {
			$params['conditions']['ActivityPackage.id <>'] = $id;
		}
		$this->set('upsellExclusions', $ActivityPackage->find('list', $params));

		$this->Translation->adminTranslationFormFields();
		$this->set('upsellFields', $this->_adminFormUpsellFields());
		$this->view = 'BuzzBookings./ActivityPackages/admin_form';

		return;
	}

	protected function _adminFormUpsellFields() {
		return array(
			'UpsellApplicableActivity.UpsellApplicableActivity' => array(
				'label' => __('Upsell Applicable Activities'),
				'type' => 'multicheck'
			),
			'UpsellExclusion.UpsellExclusion' => array(
				'label' => __('Upsell Exclude Packages'),
				'type' => 'multicheck'
			)
		);
	}

/**
 * Admin form fields
 *
 * @return array
 */
	protected function _adminFormFields() {
		$fields = parent::_adminFormFields();

		$fields['ActivityPackage.participants']['type'] = 'select';

		return $fields;
	}

/**
 * Populate admin lookups
 *
 * @return void
 */
	protected function _adminPopulateLookups() {
		$ActivityPackage = $this->{$this->modelClass};

		$activities = $ActivityPackage->Activity->find('list');
		$upsellApplicableActivities = $activities;
		if ($ActivityPackage->Activity->getMultiExperience()) {
			// Remove the multi-experience activity from upsell applicable
			// activities as there can't be any bookable upsells for
			// multi-experience bookings.
			unset($upsellApplicableActivities[$ActivityPackage->Activity->getMultiExperience()]);
		}
		$this->set(compact('activities', 'upsellApplicableActivities'));

		$participants = array_combine(range(1, 10), range(1, 10));
		array_unshift($participants, __('Private Hire'));
		$this->set(compact('participants'));

		return;
	}

}
